package main

import (
	"fmt"
	"log"
	"strings"

	"golang.org/x/net/html"
)

func main() {
	htmlStr := `
<!DOCTYPE html>
<html lang="en-US">
<head>
    <!-- Global site tag (gtag.js) - Google Analytics -->
    <script async src="https://www.googletagmanager.com/gtag/js?id=UA-154878332-1"></script>
    <script>
      window.dataLayer = window.dataLayer || [];
      function gtag(){dataLayer.push(arguments);}
      gtag('js', new Date());

      gtag('config', 'UA-154878332-1');
    </script>

	<meta charset="utf-8" />
	<meta name="viewport" content="width=device-width, initial-scale=1.0">

	<link type='text/css' rel='stylesheet' href="/css/styles.css?r=13" />

	<link rel='apple-touch-icon' href="/images/apple-touch-icon.png" sizes="114x114" />
	<link rel="icon" type="image/png" href="/images/favicon.ico" sizes="32x32">

	<script src="//ajax.googleapis.com/ajax/libs/jquery/1.11.0/jquery.min.js"></script>
	<script src="/js/libs/jquery.cookie.js"></script>
	<script src="https://maps.googleapis.com/maps/api/js?v=3.exp&amp;sensor=false"></script>
  <script src="/js/navigation.js?r=9"></script>
<TITLE>HB0030</TITLE>
<script language="javascript" src="/js/bill.js?r=7"></script>
<script type="text/javascript">
$(document).ready(function() {
initBillText('HB0030S03');
initIsTracked('HB0030');
});
</script>
<link rel="stylesheet" type="text/css" href="/css/bill.css?r=3">
<link rel="stylesheet" type="text/css" href="/css/hermesModified.css?r=5">
</head>

<body>
    <!-- <div id="alert-div">
        <div>
            <svg version="1.1" id="Layer_1" xmlns="http://www.w3.org/2000/svg" xmlns:xlink="http://www.w3.org/1999/xlink" x="0px" y="0px"
             viewBox="0 0 154.6 156.6" style="enable-background:new 0 0 154.6 156.6;" xml:space="preserve">
            <style type="text/css">
                .alert0{fill:none;stroke:#FFFFFF;stroke-width:11;stroke-miterlimit:10;}
                .alert1{fill:#FFFFFF;}
                .alert2{font-family:'MyriadPro-Regular';}
                .alert3{font-size:133px;}
            </style>
            <circle class="alert0" cx="77.6" cy="77.6" r="70.5"/>
            <g class="st1">
                <path class="alert1" d="M69.8,117.9c0-4.8,3.3-8.2,7.8-8.2c4.8,0,7.8,3.5,7.8,8.2c0,4.7-3.1,8.2-7.8,8.2
                    C73,126.1,69.8,122.5,69.8,117.9z M73.1,98.8L71.3,35H84l-1.9,63.8H73.1z"/>
            </g>
		</svg>  
        le.utah.gov will be down for maintenance September 8, 2023 from 5pm-8pm
        </div>
    </div> -->
	<header>
		<div class="overlay"></div>
		<nav>
			<!-- settings.shtml -->
            <div class="skip-links" tabindex="0">
                <ul>
                    <li>Accessibility</li>
                    <li>Use the Settings Button to view other accessibility Settings</li>
                    <li><a href="#main-content" tabindex="0" id="skip-btn">Skip to Content</a></li>
                </ul>
            </div>
			<div id="settingsNav">
                <div id="dateline">
                    <div id="button-nav">
                        <div id="settings-section">
                            <button aria-controls="search-div" id="toggle-search">
                                Search <svg class="search-icon" xmlns="http://www.w3.org/2000/svg" viewBox="15 15 20 20"><path fill="#DBDBDB" d="M33.9 34.9c-.3 0-.5-.1-.8-.3l-6.2-6-.6.3c-1.2.7-2.5 1.1-3.8 1.1-2 0-3.9-.8-5.3-2.2-2.9-2.9-2.9-7.6 0-10.5 1.4-1.4 3.3-2.2 5.3-2.2s3.9.8 5.3 2.2c2.4 2.4 2.9 6.3 1.1 9.2l-.4.5 6.1 5.9c.4.4.5 1.1 0 1.6-.2.2-.4.4-.7.4zM22.5 16.6c-1.6 0-3 .6-4.1 1.7-2.3 2.3-2.3 6 0 8.2 1.1 1.1 2.6 1.7 4.1 1.7 1.6 0 3-.6 4.1-1.7 2.3-2.3 2.3-6 0-8.2-1.1-1.1-2.5-1.7-4.1-1.7z"/></svg>
                            </button>
                            <button aria-controls="settings" aria-label="view accessibility settings" id="toggleSettings" tabindex="0">
                                <span>Settings</span>
                                <svg id="Layer_1" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100"><style>.st0{fill:#dbdbdb}</style><path class="st0" d="M96.8 40.1h-7.9c-1.1-3.6-2.5-7.2-4.3-10.5l5.8-5.8c1.4-1.4 1.4-3.2 0-4.7L81 9.7c-1.4-1.4-3.2-1.4-4.7 0l-5.8 5.8c-3.2-2.2-6.8-3.2-10.4-4.3v-8c0-1.8-1.8-3.2-3.2-3.2H43.5c-1.8 0-3.2 1.8-3.2 3.2v7.9c-3.6 1.1-7.2 2.5-10.4 4.3l-5.8-6.1c-1.4-1.4-3.2-1.4-4.7 0L10 19c-1.4 1.4-1.4 3.2 0 4.7l5.8 5.8c-2.2 3.2-3.2 6.9-4.3 10.5H3.2C1.4 40 0 41.8 0 43.2v13.4c0 1.8 1.8 3.2 3.2 3.2h7.9c1.1 3.6 2.5 7.2 4.3 10.5l-5.8 5.8c-1.4 1.4-1.4 3.2 0 4.7l9.4 9.4c1.4 1.4 3.2 1.4 4.7 0l5.8-5.8c3.2 2.2 6.8 3.2 10.4 4.3v7.9c0 1.8 1.8 3.2 3.2 3.2h13.3c1.8 0 3.2-1.8 3.2-3.2v-7.9c3.6-1.1 7.2-2.5 10.4-4.3l5.8 5.8c1.4 1.4 3.2 1.4 4.7 0l9.4-9.4c1.4-1.4 1.4-3.2 0-4.7l-5.8-5.8c2.2-3.2 3.2-6.9 4.3-10.5h8.3c1.8 0 3.2-1.8 3.2-3.2V43.3c.1-1.1-1.7-3.2-3.1-3.2zM49.6 69c-10.1 0-18.3-8.3-18.3-18.4s7.9-18.8 18.3-18.8S68 40.1 68 50.2 59.4 69 49.6 69z"/></svg>
                            </button>
                            <div id="login-div">
                                <a href="/tracking/tracking.jsp" id="toploginbutton" title="Login">
                                    <span id="loginspan">Login</span>
                                    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100"><path fill="#FFF" d="M50 0C22.4 0 0 22.4 0 50s22.4 50 50 50 50-22.4 50-50S77.6 0 50 0zm-8.4 54c0-.1 0-.1 0 0zm41.7 23c.1-.5.1-1 .2-1.5v-.4c0-1.6.1-3.2-.4-4.7-.2-.9-.6-1.8-1.2-2.6v-.1c-.4-.5-.9-1-1.3-1.6-.6-.5-1.1-.9-1.7-1.4-1.1-.6-2.3-1.3-3.4-1.9l-.6-.3c-1.4-.5-2.8-.9-4.2-1.4-1-.3-2-.5-3-.8-.9-.2-1.9-.5-2.8-.7-.8-.2-1.7-.5-2.5-.7-.4-.2-.9-.3-1.3-.5-1-.4-2-.9-2.5-2 0-1.1-.1-2.1-.1-3.2.3-.4.5-.8.8-1.2 1.7-2.6 2.7-5.4 3.4-8.4.1-.5.3-.8.7-1.1.9-.6 1.8-1.3 2-2.4.4-1.4.6-2.8.7-4.2.1-.9-.3-1.2-1.2-.9 0-.1 0-.3.1-.4.4-1.9.5-3.8.2-5.7-.7-4.3-3-7.6-6.8-9.8-4.2-2.4-8.6-2.8-13.3-1.8-4.3 1-7.4 3.5-9.5 7.4-1.7 3.3-1.7 6.7-1.1 10.2H34c-.5 0-.8.3-.9.7 0 .3-.1.6 0 .8.2.8.4 1.7.5 2.5.2.9.6 1.6 1.2 2.3.3.3.6.6.8.9l.3.3.6.6c.2.7.3 1.3.5 2 .4 1.1.7 2.2 1.1 3.2.4.9.9 1.8 1.3 2.7.5.8 1.1 1.6 1.6 2.4.1.2.2.4.2.6v1.4c.1 1.2-.6 2.1-1.6 2.6-1.2.5-2.4 1-3.7 1.4-2.9.8-5.8 1.5-8.7 2.4-2.6.8-5.1 1.9-7.2 3.6-2.2 1.8-3.6 4-3.7 6.9-.1 1.5 0 3.1.1 4.6-6.2-7.6-9.5-17-9.5-26.9 0-11.5 4.5-22.2 12.6-30.3 8.3-8 19-12.5 30.5-12.5s22.2 4.5 30.3 12.6c8.1 8.1 12.6 18.9 12.6 30.3 0 10-3.4 19.4-9.6 27z"/></svg>
                                </a>
                            </div>
                        </div>
                        <div id="stream-meeting"></div>
                    </div>
                </div>
                <div id="search-div">
                    <div>
                        <form id="navSearch" action="/solrsearch.jsp" onsubmit="return doNavSearch(this)" method="get">
                            <input tabindex="-1" type="text" name="request" aria-label="Search le.utah.gov" placeholder="Search le.utah.gov">
							<input type="hidden" name="stype" class="hiddenStype" value="">
                            <button tabindex="-1"  type="submit">Search</button>
                        </form>
                    </div>
                </div>
			</div>

			<!-- END settings.shtml -->
        <div id="fullNavContainer">
            <div id="fullNav">
                <a id="logo" href="https://le.utah.gov/" title="Home">
                    <div>
                        <img src="/images/logos/web-logo-horizontal.png" alt="Utah State Legislature Home">
                    </div>
                </a>
                <button id="menuOpen" aria-controls="mainNav" aria-label="Open Menu" tabindex="0"><svg class="menu" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 58.2 40.2"><path d="M0 16.6h58.2v7H0zM0 0h58.2v7H0zm0 33.2h58.2v7H0z" fill="#FFF"/></svg></button>
                <ul class="mainNav" id="mainNav">
                    <li>
                        <button id="menuClose" aria-controls="mainNav" aria-label="Close Menu"><svg class="close" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100"><path fill="#fff" d="M100 10.1L89.9 0 50 39.9 10.1 0 0 10.1 39.9 50 0 89.9 10.1 100 50 60.1 89.9 100 100 89.9 60.1 50 100 10.1z"></path></svg></button>
                    </li>
                    <li class="menu-item" id="leg-menu-item">
                        <a href="/Documents/find.htm" class="has-drop">Legislators</a>
                        <div id="legislator-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                  <button class="nav-header" aria-controls="all-list" aria-haspopup="true" tabindex="0">All Legislators</button>
                                    <a href="/Documents/find.htm" class="sub-header">All Legislators</a>
                                    <ul id="all-list">
                                        <li class="hide-large"><a  href="/Documents/find.htm">Find Legislators</a></li>
                                        <li><a href="/asp/roster/roster.asp">By Session (1896-Current)</a></li>
                                        <li><a href="/asp/roster/complist.asp">Alphabetical (Historical)</a></li>
                                        <li><a href="/GIS/findDistrict.jsp">Find by Address/Map</a></li>
                                        <li><a href="/sessions/sessions.jsp">Sessions</a></li>
                                        <li><a href="/FloorCalendars/">Reading Calendars</a></li>
                                        <li><a href="/asp/schedule/journal.asp">Journals</a></li>
                                        <li><a href="/sessionSchedule/sessdates.jsp">Session Dates</a></li>
                                    </ul>
                                </div>
                                <div>
                                    <a href="https://house.utleg.gov/" class="sub-header">House</a>
                                    <button class="nav-header" aria-controls="house-list" aria-haspopup="true" tabindex="0">House</button>
                                    <ul id="house-list">
                                        <li class="hide-large"><a href="https://house.utleg.gov/">House Home</a></li>
                                        <li><a href="https://house.utleg.gov/about/">About the House</a></li>
                                        <li><a href="https://house.utleg.gov/house-leadership/">Leadership</a></li>
                                        <li><a href="https://house.utleg.gov/house-members/">Roster</a></li>
                                        <li><a href="/asp/seating/hseat.asp">Seating Chart</a></li>
                                        <li><a href="https://house.utleg.gov/conflict-disclosures/">Conflict of Interest Forms</a></li>
                                        <li><a href="/asp/audio/index.asp?House=H">Past Floor Debates</a></li>
                                    </ul>
                                </div>
                                <div>
                                    <a href="https://senate.utah.gov/" class="sub-header" >Senate</a>
                                    <button class="nav-header" aria-haspopup="true" aria-controls="senate-list" tabindex="0">Senate</button>
                                    <ul id="senate-list">
                                        <li class="hide-large"><a href="https://senate.utah.gov/">Senate Home</a></li>
                                        <li><a href="https://senate.utah.gov/about-the-senate/">About the Senate</a></li>
                                        <li><a href="https://senate.utah.gov/leadership/">Leadership</a></li>
                                        <li><a href="https://senate.utah.gov/senate-roster/">Roster</a></li>
                                        <li><a href="/asp/seating/sseat.asp">Seating Chart</a></li>
                                        <li><a href="/sessions/es.jsp">Extraordinary Sessions</a></li>
                                        <li><a href="/asp/audio/index.asp?House=S">Past Floor Debates</a></li>
                                        <li><a href="https://disclosures.utah.gov/Search/PublicSearch?type=PCC">Disclosure Forms</a></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </li>
                    <li class="menu-item">
                        <a href="/bills/bills_By_Session.jsp" class="has-drop">Bills</a>
                        <div id="bills-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                    <a href="/bills/bills_By_Session.jsp" class="big-header">View Bills</a>
                                    <ul>
                                        <li><a href="/billlist.jsp?session=2025GS">2025 Bills</a></li>
                                        <li><a href="/asp/billsintro/index.asp">Browse by Session</a></li>
                                        <li><a href="/asp/passedbills/passedbills.asp">Passed Bills</a></li>

                                        <li><a href="/solrsearch.jsp?ktype=Bill">Keyword Search</a></li>
                                        <li><a href="/tracking/tracking.jsp">Tracking Service</a></li>
                                        <li><a href="http://images.archives.utah.gov/cdm/search/collection/432n!428/searchterm/working%20bills/field/all/mode/all/conn/and/order/identi/ad/asc">Working Bills (1896-1989)</a></li>
                                        <!-- <li><a href="https://image.le.utah.gov/imaging/bill.asp">Bill Drafting/Research Files (1990-Ongoing)</a></li> -->
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </li>
                    <li class="menu-item">
                        <a href="/xcode/code.html" class="has-drop">Code</a>
                        <div id="code-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                    <a href="/xcode/code.html" class="big-header">Utah Code </a>
                                    <ul>
                                        <li><a href="/Documents/code_const.htm">Code and Constitution</a></li>
                                        <li><a href="/solrsearch.jsp?ktype=Code">Keyword Search</a></li>
                                        <li><a href="/xcode/constitution.html">Utah Constitution</a></li>
                                        <li><a href="/documents/conconv/utconstconv.htm">Constitutional Convention</a></li>
										<li><a href="/documents/laws-recent.htm">Laws of Utah 2014-ongoing</a></li>
										<li><a href="https://onlinelibrary.utah.gov/library-resource/heinonline/">Historical Laws of Utah</a></li>
                                        <li><a href="/xcode/R.html">Legislative Rules</a></li>
                                        <li><a href="https://adminrules.utah.gov/">Utah Administrative Rules</a></li>
                                    </ul>
                                </div>
                            </div>

                        </div>
                    </li>
                    <li class="menu-item">
                        <a href="/asp/interim/Main.asp?ComType=All&List=2" class="has-drop">Committees</a>
                        <div id="committees-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                    <a href="/asp/interim/Main.asp?ComType=All&List=2" class="big-header">All Committees</a>
                                    <ul>
                                        <li><a href="/asp/interim/Main.asp?ComType=App&List=2">Appropriations</a></li>
                                        <li><a href="/asp/interim/Main.asp?ComType=Com&List=2">Commissions</a></li>
                                        <li><a href="/asp/interim/Main.asp?ComType=Cnf&List=2">Confirmation</a></li>
                                        <li><a href="/asp/interim/Main.asp?ComType=Int&List=2">Interim</a></li>
                                        <li><a href="/asp/interim/Main.asp?ComType=Std&List=2">Standing</a></li>
                                        <li><a href="/asp/interim/Main.asp?ComType=Sub&List=2">Subcommittees</a></li>
                                        <li><a href="/asp/interim/Main.asp?ComType=Tsk&List=2">Task Forces</a></li>
                                        <li><a href="/asp/billsintro/committeebills.asp">Bills in Committees</a></li>
                                        <!-- <li><a href="https://image.le.utah.gov/imaging/History.asp">Interim Committee Histories (1990-Ongoing)</a></li> -->
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </li>
                     <li class="menu-item">
                        <a href="https://lag.utleg.gov/" class="has-drop">Audits</a>
                        <div id="audits-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                        <ul>
                                            <li><a href="https://lag.utleg.gov/audits_current.jsp">New Audits</a></li>
                                            <li><a href="https://le.utah.gov/committee/committee.jsp?com=SPEAUD">Audit Subcommittee</a></li>
                                            <li><a href="https://lag.utleg.gov/best_practices.jsp">Government Excellence</a></li>
                                            <li><a href="https://lag.utleg.gov/annual_report.jsp">Annual Reports</a></li>
                                            <li><a href="https://lag.utleg.gov/">Office of the Legislative Auditor General</a></li>
                                        </ul>
                                </div>
                            </div>
                        </div>
                    </li>
                    <li class="menu-item">
                        <a href="https://budget.utah.gov/" class="has-drop">Budget</a>
                        <div id="budget-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                    <a href="https://budget.utah.gov/" class="big-header">Budget.Utah.gov</a>
                                    <ul>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=stateBudget">State Budget (PDF)</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=cobi">COBI</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=quickFacts">Quick Facts (PDF)</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=fiscalHealth">Fiscal Health</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=taxpayerReceipt">Taxpayer Receipt</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=budgetVisualizer">Data Visualizer</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=appsByBills">Budget Bills</a></li>
                                        <li><a href="/CobiServlet/cobi/BudgetRD?key=appsBySubcommittees">Budget Committees</a></li>
                                        <li><a href="/asp/lfa/lfareports.asp">Budget Publications</a></li>
                                        <li><a href="https://budget.utah.gov/products/aboutLFA/">Office of the Legislative Fiscal Analyst</a></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </li>
                    <li class="menu-item"style="min-width: 120px;">
                        <a href="/lrgc/home.html" class="has-drop">Research and Legal</a>
                        <div id="research-div" class="drop-down">
                            <div class="nav-div">
                                <div>
                                    <ul>
                                        <li ><a href="/lrgc/home.html">Office of Legislative Research and General Counsel</a></li>
                                        <li><a href="/lrgc/publications.html">Publications</a></li>
                                        <li><a href="/lrgc/bill-data.html">Bill Data</a></li>
                                        <li><a href="/lrgc/researchMaterials.htm">Legislative Information</a></li>
                                        <li><a href="/AgencyRP/index.jsp">Agency Reporting</a></li>
                                        <li><a href="/lawSearch.jsp">Advanced Law Search</a></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </li>
                </ul>
            </div>
        </div>
		</nav>
        <div class="modal" id="settings">
            <div id="settings-modal">
                <button aria-label="close" id="close-settings" class="close">
                    <svg class="close" xmlns="http://www.w3.org/2000/svg" viewBox="0 0 100 100">
                        <path fill="#fff" d="M100 10.1L89.9 0 50 39.9 10.1 0 0 10.1 39.9 50 0 89.9 10.1 100 50 60.1 89.9 100 100 89.9 60.1 50 100 10.1z"></path>
                    </svg>
                </button>
                <h2>Additional Accessibility Settings</h2>
                <p class="settings">
                    <button class="defaultStyles">Default Settings</button>
                    <button class="highContrast">High Contrast</button>
                    <button class="textOnly">Text Only</button>
                </p>
                <div id="fontSizer">
                    <span>Font Size:</span>
                    <button title="Font size smaller" aria-label="Font size smaller" class="fontsize small" data-size="smallFont">A</button>
                    <button title="Font size default" aria-label="Font size default" class="fontsize default">A</button>
                    <button title="Font size larger" aria-label="Font size larger" class="fontsize large" data-size="largeFont">A</button>
                </div>
            </div>


        </div>
	</header>

<div id="main-block">
	<main id="main-content">
<ul id="breadcrumb">
<li><a href="/">Home</a></li>
<li><a href="/~2024/2024.HTM/">2024 General Session</a></li>
<li>H.B. 30</li>
</ul>
<h3 class="heading">H.B. 30 Road Rage Amendments</h3>
<ul class="tab small activator">
	 <li class="three left"><a id="activator-billText" class="billText active">Bill Text</a></li>
    <li class="three  left"><a id="activator-billStatus" class="billStatus">Status</a></li>
    <li class="three  left"><a id="activator-billVideo" class="billVideo">Hearings/Debate</a></li>
</ul>
<div id="billText" class="slot active">
  <div id="billinfo" class="blue">
<div id="legislatordiv"><table width="100%">	<tr>    	<td>        <div id="billsponsordiv">            <B>Bill Sponsor: </B><br>            	<a href="/asp/roster/leglookup.asp?house=H&Leg=Cutler, P." target="_blank" legid="CUTLEP" ><img src="/images/legislator/CUTLEP.jpg" width="100px"><br>Rep. Cutler, Paul A.</a>        </div>    	</td>       <td>            <div id="floorsponsordiv">                <B>Floor Sponsor: </B><br>                    <a href="/asp/roster/leglookup.asp?house=S&Leg=Weiler, T." target="_blank" ><img src="/images/legislator/WEILET.jpg" width="100px"><br>Sen. Weiler, Todd D.</a>            </div>        </td>	</tr></table><ul class="billinfoulm"><li><B>Substitute Sponsor: </B><a href="/asp/roster/leglookup.asp?house=H&Leg=Cutler, P." >Rep. Cutler, Paul A.</a></li></ul><ul><li><B>CoSponsor(s):</B><ul><TABLE><TR><TD nowrap><FONT face="Arial" size=-1>&nbsp;&nbsp;Acton, C.K.</FONT></TD><TD nowrap><FONT face="Arial" size=-1>&nbsp;&nbsp;Pierucci, C.</FONT></TD></TR><TR><TD nowrap><FONT face="Arial" size=-1>&nbsp;&nbsp;Stoddard, A.</FONT></TD></TR></TABLE></ul></li></ul></div><ul class="billinfoulm"><li><B>Drafting Attorney: </B>Jacqueline Carlton</li><li><B>Fiscal Analyst: </B>Gary R. Syphus</li></ul><hr>

<ul id="billTextDiv" class="billinfoulm"><li><b>Bill Text</b><ul><li><a onclick="setBill4('/~2024/bills/hbillint/HB0030S03.htm' ,'Introduced','introducedspan','HB0030S03');" title="Display introduced version of bill">Introduced</a> <A HREF="/~2024/bills/hbillint/HB0030S03.pdf" class="nlink" title="Open PDF" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A> <A id="introducedhtmllink" HREF="/~2024/bills/hbillint/HB0030S03.htm" class="nlink"></A> <span id="introducedspan" class="dispspan"></span></li><li><a onclick="setBill4('/~2024/bills/hbillamd/HB0030S03.htm' ,'Amended','amendedspan','HB0030S03');" title="Display amended version of bill">Amended</a> <A HREF="/~2024/bills/hbillamd/HB0030S03.pdf" class="nlink" title="Open PDF" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A> <A id="amendedhtmllink" HREF="/~2024/bills/hbillamd/HB0030S03.htm" class="nlink"> <span id="amendedspan" class="dispspan"></span></A><ul><li><A HREF="/~2024/bills/hbillamd/HB0030S03.amdx.pdf" class="nlink" target="_blank" title="Open PDF">Amended Pages Only</A></li></ul></li><li><a onclick="setBill4('/~2024/bills/xmlEnrolled/HB0030.xml' ,'Enrolled','enrolledspan','HB0030S03');" title="Display enrolled version of bill">Enrolled</a> <A HREF="/~2024/bills/hbillenr/HB0030.pdf" class="nlink" title="Open PDF" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A> <A id="enrolledhtmllink" HREF="/~2024/bills/xmlEnrolled/HB0030.xml" class="nlink"></A> <span id="enrolledspan" class="dispspan"></span></li></ul></li></ul><hr>
<ul id="billversionsDiv" class="billinfoulm"><li><b>Other Versions</b><ul><li><A HREF="javascript:void(0);" onclick="$('#item4').toggle()" class="mitem">H.B. 30</A><DIV STYLE="display: none" id=item4 class="otherversionbox"><B>Substitute Sponsor: </B><BR><A HREF="javascript:void(0);" onclick="$('#item5').toggle()" class="mitem"><B>CoSponsor(s):</B></A><DIV id="item5" STYLE="display: none; background-color: #EFEFEF; border-width:2px; border-style:outset; border-color:black"><TABLE><TR><TD nowrap><FONT face="Arial" size=-1>&nbsp;&nbsp;Acton, C.K.</FONT></TD><TD nowrap><FONT face="Arial" size=-1>&nbsp;&nbsp;Pierucci, C.</FONT></TD></TR><TR><TD nowrap><FONT face="Arial" size=-1>&nbsp;&nbsp;Stoddard, A.</FONT></TD></TR></TABLE></DIV><ul><li><A onclick="setBill4('/~2024/bills/hbillint/HB0030.htm' ,'Introduced','introducedspanHB0030','HB0030');" title="Display introduced version of bill">Introduced</A> <A HREF="/~2024/bills/hbillint/HB0030.pdf" class="nlink" title="Open PDF" target="_blank"><img src="/images/pdf.gif" height="17" width="15" ></A> <span id="introducedspanHB0030" class="dispspan"></span></li><li><A onclick="setBill4('/lfa/fnotes/2024/HB0030.fn.htm' ,'Fiscal Note','fiscalnotespanHB0030','HB0030');" title="Display Fiscal Note">Fiscal Note</a> <A HREF="/lfa/fnotes/2024/HB0030.fn.pdf" class="nlink" title="Open PDF" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A> <span id="fiscalnotespanHB0030" class="dispspan"></span></li><li><a href="/~2024/transmit/HB030H10.pdf" class="nlink">House Transmittal Letter 1</a></li><li><a href="/~2024/transmit/HB030S10.pdf" class="nlink">Senate Transmittal Letter 1</a></li></ul></div></li><li><A HREF="javascript:void(0);" onclick="$('#item6').toggle()" class="mitem">H.B. 30 1st Substitute (Not Adopted)</A><DIV STYLE="display: none" id=item6 class="otherversionbox"><B>Substitute Sponsor: </B>Cutler, P.<BR><ul><li><A HREF="/~2024/bills/hbillint/HB0030S01.pdf" class="nlink" title="Open PDF" target="_blank">Text</A> <span id="introducedspanHB0030S01" class="dispspan"></span></li><li><A HREF="/lfa/fnotes/2024/HB0030S01.fn.pdf" class="nlink">Fiscal Note</a> <img title="Has a substantial fiscal impact" src="/images/fiscalimp2.png"></li><li><A HREF="/~2024/bills/hbillint/HB0030S01_ComparedWith_HB0030.pdf" class="nlink">HB0030 comparison</A></li></ul></div></li><li><A HREF="javascript:void(0);" onclick="$('#item7').toggle()" class="mitem">H.B. 30 2nd Substitute (Not Adopted)</A><DIV STYLE="display: none" id=item7 class="otherversionbox"><B>Substitute Sponsor: </B>Cutler, P.<BR><ul><li><A HREF="/~2024/bills/hbillint/HB0030S02.pdf" class="nlink" title="Open PDF" target="_blank">Text</A> <span id="introducedspanHB0030S02" class="dispspan"></span></li><li><A HREF="/lfa/fnotes/2024/HB0030S02.fn.pdf" class="nlink">Fiscal Note</a> <img title="Has a substantial fiscal impact" src="/images/fiscalimp2.png"></li><li><A HREF="/~2024/bills/hbillint/HB0030S02_ComparedWith_HB0030S01.pdf" class="nlink">HB0030S01 comparison</A></li></ul></div></li></ul></li></ul><hr>
<ul class="billinfoulm"><li><b>Related Documents </b><ul><li><a onclick="setBill4('/lfa/fnotes/2024/HB0030S03.fn.htm' ,'Fiscal Note','fiscalnotespan','HB0030S03');" title="Display Fiscal Note">Fiscal Note</a> <A HREF="/lfa/fnotes/2024/HB0030S03.fn.pdf" class="nlink" title="Open PDF" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A> <span id="fiscalnotespan" class="dispspan"></span></li><li><A HREF="/~2024/pamend/hb0030s03.hfap.01.pdf" class="nlink">House Floor Amendment 1(passed)</A></li><li><A HREF="/~2024/bills/hbillint/HB0030S03_ComparedWith_HB0030.pdf" class="nlink">HB0030 comparison</A></li></ul></li></ul><hr>
<ul class="billinfoulm"><li><b>Information</b><ul><li><B>Last Action: </B>18 Mar 2024, Governor Signed</li><li><B>Last Location: </B>Lieutenant Governor's office for filing</li></ul></li></ul><hr>
<ul id="billTextDiv" class="billinfoulm"><li><b>Similar Bills</b><ul><li><A HREF="/ASP/RelatedBill/similar.asp?scode=02176u&Year=2024" class="nlink">Crimes</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=02732&Year=2024" class="nlink">Driver License</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=02751&Year=2024" class="nlink">Roads/Highways</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=02778&Year=2024" class="nlink">Motor Vehicles</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=02828&Year=2024" class="nlink">Transportation</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=03071&Year=2024" class="nlink">Weapons</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=05177u&Year=2024" class="nlink">Punishment</A></li><li><A HREF="/ASP/RelatedBill/similar.asp?scode=n0082&Year=2024" class="nlink">Fines</A></li></ul></li></ul><hr>

  </div>
<div id="docheader" class=""></div>
<div id="billbox" class=""></div>
</div>
<div id="billStatus" class="slot">
<span class="heading">Bill Status / Votes</span><HR>
<DIV ><div style="width:100%; text-align:right"><span style="border:thin solid #BEC9E0"><font color="#3333FF"> &bull; Senate Actions</font> <font color="#CC0000"> &bull; House Actions</font> <font color="#25B223"> &bull; Fiscal Actions</font> <font color="black"> &bull; Other Actions</font> </span></div><TABLE width="100%"><TR><TD><FONT face="Arial" size=-1><B>Date</B></FONT></TD><TD><FONT face="Arial" size=-1><B>Action</B></FONT></TD><TD><FONT face="Arial" size=-1><B>Location</B></FONT></TD><TD><FONT face="Arial" size=-1><B>Vote</B></FONT></TD></TR><TR><TD><FONT face="Arial" color="black" size=-1>12/19/2023 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Bill Numbered but not Distributed</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Legislative Research and General Counsel</FONT></TD><TD><FONT face="Arial" color="black" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="black" size=-1>12/19/2023 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Numbered Bill Publicly Distributed</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Legislative Research and General Counsel</FONT></TD><TD><FONT face="Arial" color="black" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>1/10/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ received bill from Legislative Research</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Clerk of the House</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>1/16/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ 1st reading (Introduced)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House Rules Committee</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>1/25/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ received fiscal note from Fiscal Analyst</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House Rules Committee</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>1/31/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ to standing committee</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House Law Enforcement and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="black" size=-1>2/9/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>House Comm - Substitute Recommendation from # 0 to # 3</FONT></TD><TD><FONT face="Arial" color="black" size=-1>House Law Enforcement and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="black" size=-1><a href="/mtgvotes.jsp?voteid=31346">7 0 5</a></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="black" size=-1>2/9/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>House Comm - Favorable Recommendation</FONT></TD><TD><FONT face="Arial" color="black" size=-1>House Law Enforcement and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="black" size=-1><a href="/mtgvotes.jsp?voteid=31347">7 0 5</a></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>2/12/2024 (10:18:50 AM)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ comm rpt/ substituted</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House Law Enforcement and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>2/12/2024 (10:18:51 AM)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ 2nd reading</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House 3rd Reading Calendar for House bills</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#25B223" size=-1>2/12/2024 </FONT></TD><TD><FONT face="Arial" color="#25B223" size=-1>LFA/ fiscal note sent to sponsor</FONT></TD><TD><FONT face="Arial" color="#25B223" size=-1>House 3rd Reading Calendar for House bills</FONT></TD><TD><FONT face="Arial" color="#25B223" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#25B223" size=-1>2/12/2024 </FONT></TD><TD><FONT face="Arial" color="#25B223" size=-1>LFA/ fiscal note publicly available</FONT></TD><TD><FONT face="Arial" color="#25B223" size=-1>House 3rd Reading Calendar for House bills</FONT></TD><TD><FONT face="Arial" color="#25B223" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>2/16/2024 (11:43:56 AM)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ 3rd reading</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House 3rd Reading Calendar for House bills</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>2/16/2024 (11:49:30 AM)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ floor amendment # 1</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House 3rd Reading Calendar for House bills</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1><a href="/DynaBill/svotes.jsp?sessionid=2024GS&voteid=660&house=H">Voice vote</a></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>2/16/2024 (11:58:00 AM)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ passed 3rd reading</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Senate Secretary</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1><a href="/DynaBill/svotes.jsp?sessionid=2024GS&voteid=661&house=H">51 17 7</a></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>2/16/2024 (11:58:02 AM)</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ to Senate</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Senate Secretary</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/16/2024 </FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ received from House</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Waiting for Introduction in the Senate</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#3333FF" size=-1>2/16/2024 </FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ 1st reading (Introduced)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate Rules Committee</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/20/2024 </FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ to standing committee</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate Judiciary, Law Enforcement, and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="black" size=-1>2/22/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Senate Comm - Favorable Recommendation</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Senate Judiciary, Law Enforcement, and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="black" size=-1><a href="/mtgvotes.jsp?voteid=32263">3 0 3</a></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/22/2024 (2:19:24 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ committee report favorable</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate Judiciary, Law Enforcement, and Criminal Justice Committee</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#3333FF" size=-1>2/22/2024 (2:19:25 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ placed on 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/27/2024 </FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ 2nd Reading Calendar to Rules</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate Rules Committee</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 </FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ Rules to 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 (12:09:34 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ 2nd & 3rd readings/ suspension</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 (12:09:48 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ circled</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1><a href="/DynaBill/svotes.jsp?sessionid=2024GS&voteid=1727&house=S">Voice vote</a></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 (8:05:19 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ uncircled</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate 2nd Reading Calendar</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1><a href="/DynaBill/svotes.jsp?sessionid=2024GS&voteid=1854&house=S">Voice vote</a></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 (8:11:13 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ passed 2nd & 3rd readings/ suspension</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate President</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1><a href="/DynaBill/svotes.jsp?sessionid=2024GS&voteid=1855&house=S">23 5 1</a></FONT></TD></TR><TR><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 (8:11:14 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ signed by President/ returned to House</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>House Speaker</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#3333FF" size=-1>2/28/2024 (8:11:15 PM)</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>Senate/ to House</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1>House Speaker</FONT></TD><TD><FONT face="Arial" color="#3333FF" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>2/29/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ received from Senate</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House Speaker</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>2/29/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ signed by Speaker/ sent for enrolling</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Legislative Research and General Counsel / Enrolling</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="black" size=-1>2/29/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Bill Received from House for Enrolling</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Legislative Research and General Counsel / Enrolling</FONT></TD><TD><FONT face="Arial" color="black" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="black" size=-1>2/29/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Draft of Enrolled Bill Prepared</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Legislative Research and General Counsel / Enrolling</FONT></TD><TD><FONT face="Arial" color="black" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="black" size=-1>3/7/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Enrolled Bill Returned to House or Senate</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Clerk of the House</FONT></TD><TD><FONT face="Arial" color="black" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>3/7/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ enrolled bill to Printing</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Clerk of the House</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="#CC0000" size=-1>3/8/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ received enrolled bill from Printing</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Clerk of the House</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR bgcolor="#F0F0F0"><TD><FONT face="Arial" color="#CC0000" size=-1>3/8/2024 </FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>House/ to Governor</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1>Executive Branch - Governor</FONT></TD><TD><FONT face="Arial" color="#CC0000" size=-1></FONT></TD></TR><TR><TD><FONT face="Arial" color="black" size=-1>3/18/2024 </FONT></TD><TD><FONT face="Arial" color="black" size=-1>Governor Signed</FONT></TD><TD><FONT face="Arial" color="black" size=-1>Lieutenant Governor's office for filing</FONT></TD><TD><FONT face="Arial" color="black" size=-1></FONT></TD></TR></TABLE></DIV>
</div>
<div id="billVideo" class="slot">
<span class="heading">Committee Hearings/Floor Debate</span><HR>
<ul class="billinfoulm"><li><b>Committee Hearings</b><ul><li><A HREF="/committee/committee.jsp?year=2024&com=SSTJLC&mtgid=19237" class="nlink">Senate Judiciary, Law Enforcement, and Criminal Justice Committee</A><ul><li><A HREF="/~2024/agenda/SJLC0222.ag.htm" class="nlink">Agenda</a> <A HREF="/~2024/agenda/SJLC0222.ag.pdf" class="nlink" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A></li><li><A HREF="/interim/2024/html/00001775.htm" class="nlink" target="_blank">Minutes</a> <A HREF="/interim/2024/pdf/00001775.pdf" class="nlink" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></a></li>&nbsp;&nbsp;&nbsp;&nbsp;<A HREF="/~2024/comreport/HB030S10.pdf" class="nlink">Committee Report</A><BR>&nbsp;&nbsp;&nbsp;&nbsp;<A HREF="https://le.utah.gov/av/committeeArchive.jsp?timelineID=251965">Audio</A><BR></ul></li><li><A HREF="/committee/committee.jsp?year=2024&com=HSTLAW&mtgid=19326" class="nlink">House Law Enforcement and Criminal Justice Committee</A><ul><li><A HREF="/~2024/agenda/HLAW0209.ag.htm" class="nlink">Agenda</a> <A HREF="/~2024/agenda/HLAW0209.ag.pdf" class="nlink" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></A></li><li><A HREF="/interim/2024/html/00001579.htm" class="nlink" target="_blank">Minutes</a> <A HREF="/interim/2024/pdf/00001579.pdf" class="nlink" target="_blank"><img src="/images/pdf.gif" height="17" width="15"></a></li>&nbsp;&nbsp;&nbsp;&nbsp;<A HREF="/~2024/comreport/HB030H10.pdf" class="nlink">Committee Report</A><BR>&nbsp;&nbsp;&nbsp;&nbsp;<A HREF="https://le.utah.gov/av/committeeArchive.jsp?timelineID=248555">Audio</A><BR></ul></li></ul></li></ul><ul class="billinfoulm"><li><b>Floor Debates</b><ul><li><A HREF="https://le.utah.gov/av/floorArchive.jsp?markerID=126331" class="nlink">House Floor Audio, Day 32 (2/16/2024) [HB30 Road Rage Amendments, Cutler]</A></li><li><A HREF="https://le.utah.gov/av/floorArchive.jsp?markerID=127630" class="nlink">Senate Floor Audio, Day 43 (2/28/2024) [3HB30 Road Rage Amendments, Weiler]</A></li><li><A HREF="https://le.utah.gov/av/floorArchive.jsp?markerID=127618" class="nlink">Senate Floor Audio, Day 43 (2/28/2024) [HB30 Road Rage Amendments, Weiler]</A></li></ul></li></ul>
</div>
</article>
</div>
</main>

<footer>

<!-- twitter.html -->
<!--
<div id="twitter">
<div>Loading Twitter Feed...</div>
</div>
-->
<!-- END twitter.html -->

<div id="footerDetails">

<div class="footerSection" id="footerSenate">
	<a href="https://senate.utah.gov/"><div><img src="/images/logos/senate.svg" alt="Seal for Utah State Senate"><h2>State<br>Senate</h2></div></a>
    <ul>
		<li>
			350 North State, Suite 320<br>
			PO Box 145115<br>
			Salt Lake City, Utah 84114
		</li>
		<li class="telephone">Telephone: <a href="tel:8015381035">(801) 538-1408</a></li>
		<li><a href="https://senate.utah.gov" target="_blank">https://senate.utah.gov</a></li>
        <li><a href="https://senate.utah.gov/contact/" class="button">Contact a Senator</a></li>
	</ul>
</div>

<div class="footerSection" id="footerHouse">
	<a href="https://house.utleg.gov"><div><img src="/images/logos/house.svg" alt="Seal for Utah House of Representatives"><h2>House of<br> Representatives</h2></div></a>
    <ul>
		<li>
			350 North State, Suite 350<br>
			PO Box 145030<br>
			Salt Lake City, Utah 84114
		</li>
		<li class="telephone">Telephone: <a href="tel:8015381408">(801) 538-1408</a></li>
		<li><a href="https://house.utleg.gov" target="_blank">https://house.utleg.gov</a></li>
        <li><a href="https://house.utleg.gov/contact/" class="button">Contact a Representative</a></li>
	</ul>
</div>

<div class="footerSection" id="footerStaff">
    <div><a href="/Documents/staff.htm"><h2>Staff Offices</h2></a></div>
    <ul>
        <li><a href="https://lag.utleg.gov/">Legislative Auditor General</a></li>
        <li><a href="https://budget.utah.gov/products/aboutLFA/">Legislative Fiscal Analyst</a></li>
        <li><a href="/lrgc/home.html">Legislative Research and General Counsel</a></li>
        <li><a href="/legservices/legservices.htm">Legislative Services</a></li>
        <li><a href="/ncsl/utahstaffawards.htm">Staff Awards</a></li>
        <li><a href="/lrgc/researchMaterials.htm" class="button">Public Information</a></li>
	</ul>
</div>

</div>

<div id="footerNav">
	<ul>
		<li><a href="/Documents/recordsrequests.htm">Records Requests</a></li>
		<li><a href="/rfp_legal.htm">Procurement</a></li>
		<li><a href="/contact.htm">Contact the Webmaster</a></li>
		<li><a href="/jobs/jobs.htm">Job Opportunities</a></li>
		<li><a href="/faq.jsp">FAQ</a></li>
		<li><a href="/sitemap.htm">Site Map</a></li>
		<li><a href="/documents/disclaimer.htm">Terms of Use</a></li>
		<li><a href="/documents/ADAnotice.htm">ADA</a></li>
		<li><a href="http://utah.gov/">Utah.gov</a></li>
	</ul>
</div>

</footer>

<script src="/js/scripts.min.js?r=19"></script>
<script src="/js/search.js?r=15"></script>
<!--<script type="text/javascript" src="https://www.utah.gov/code/libs/uii.aggregator.min.js"></script>-->
<script>
//$.backstretch("/images/background.jpg");
/*
var lebgr = {};
lebgr.baseUrl = '/images/backgrounds/';
//lebgr.imgEl = document.querySelector('.backstretch-item img');
lebgr.backgrounds = [
'background-01.jpg',
'background-02.jpg',
'background-03.jpg',
'background-04.jpg',
'background-05.jpg',
'background-06.jpg',
];

lebgr.random = function(max) {
return Math.floor(Math.random() * (max - 0)) + 0;
};

lebgr.output = function(options) {
var backgroundName = lebgr.backgrounds[lebgr.random(lebgr.backgrounds.length)];
var backgroundUrl = lebgr.baseUrl + backgroundName;
//lebgr.imgEl.src = backgroundUrl;
$.backstretch(backgroundUrl);
};
lebgr.output();
*/
</script>

</body>
</html>

`

	doc, err := html.Parse(strings.NewReader(htmlStr))
	if err != nil {
		log.Fatal(err)
	}

	var extractText func(*html.Node)
	extractText = func(n *html.Node) {
		if n.Type == html.TextNode {
			fmt.Printf("%v\n", n.Data)
		}
		for c := n.FirstChild; c != nil; c = c.NextSibling {
			extractText(c)
		}
	}

	extractText(doc)
}
